@@ -1,26 +1,23 @@
 import transmission_rpc
 
-from bgmi import config
+from bgmi.config import cfg
 from bgmi.plugin.download import BaseDownloadService, DownloadStatus
 
 
 class TransmissionRPC(BaseDownloadService):
     def __init__(self):
         self.client = transmission_rpc.Client(
-            host=config.TRANSMISSION_RPC_URL,
-            port=config.TRANSMISSION_RPC_PORT,
-            username=config.TRANSMISSION_RPC_USERNAME,
-            password=config.TRANSMISSION_RPC_PASSWORD,
+            host=cfg.transmission.rpc_host,
+            port=cfg.transmission.rpc_port,
+            username=cfg.transmission.rpc_username,
+            password=cfg.transmission.rpc_password,
+            path=cfg.transmission.rpc_path,
         )
 
     @staticmethod
     def check_config() -> None:
         pass
 
-    @staticmethod
-    def check_dep():
-        pass
-
     def add_download(self, url: str, save_path: str):
         torrent = self.client.add_torrent(url, download_dir=save_path, paused=False)
         return torrent.hashString
