@@ -22,14 +22,6 @@ class BaseDownloadService(metaclass=abc.ABCMeta):
         :return: task id
         """
 
-    @staticmethod
-    @abc.abstractmethod
-    def check_dep() -> None:
-        """check dependencies like rpc library
-
-        :raises MissingDependencyError:
-        """
-
     @staticmethod
     @abc.abstractmethod
     def check_config() -> None:
